import { DOCUMENT, CommonModule } from '@angular/common';
import { Injectable, defineInjectable, EventEmitter, Component, ChangeDetectionStrategy, ViewEncapsulation, ChangeDetectorRef, Input, Output, ComponentFactoryResolver, ApplicationRef, Injector, Inject, inject, INJECTOR, NgModule } from '@angular/core';
import { isAndroid, BaseService } from 'ngx-weui/core';
import { trigger, state, style, transition, animate } from '@angular/animations';
import { Observable, Subscription } from 'rxjs';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ActionSheetConfig {
    constructor() {
        /**
         * 样式，默认：`ios`
         */
        this.skin = 'ios';
        /**
         * 取消文本，默认：`取消`
         */
        this.cancel = '取消';
        /**
         * 允许点击背景关闭，默认：`true`
         */
        this.backdrop = true;
    }
}
ActionSheetConfig.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */ ActionSheetConfig.ngInjectableDef = defineInjectable({ factory: function ActionSheetConfig_Factory() { return new ActionSheetConfig(); }, token: ActionSheetConfig, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ActionSheetComponent {
    /**
     * @param {?} DEF
     * @param {?} cdr
     */
    constructor(DEF, cdr) {
        this.DEF = DEF;
        this.cdr = cdr;
        this.destroied = false;
        this._shown = false;
        /**
         * 动画状态码
         */
        this._shownAnt = false;
        /**
         * 菜单内容
         */
        this.menus = [];
        /**
         * 关闭回调
         */
        this.close = new EventEmitter();
    }
    /**
     * @return {?}
     */
    get _visibility() {
        return this._shownAnt ? 'show' : 'hide';
    }
    /**
     * @private
     * @return {?}
     */
    detectChanges() {
        if (this.destroied)
            return;
        this.cdr.detectChanges();
    }
    /**
     * 显示，组件载入页面后并不会显示，显示调用 `show()` 并订阅结果。
     * @return {?}
     */
    show() {
        this.config = Object.assign({ backdrop: true, skin: 'auto' }, this.DEF, this.config);
        if (this.config.skin === 'auto') {
            this.config.skin = isAndroid() ? 'android' : 'ios';
        }
        this._shown = true;
        setTimeout((/**
         * @return {?}
         */
        () => {
            this._shownAnt = true;
            this.detectChanges();
        }), 10);
        return Observable.create((/**
         * @param {?} observer
         * @return {?}
         */
        (observer) => {
            this.observer = observer;
        }));
    }
    /**
     * 隐藏
     *
     * @param {?=} is_backdrop 是否从背景上点击
     * @return {?}
     */
    hide(is_backdrop) {
        if (is_backdrop === true && this.config.backdrop === false)
            return false;
        this._shownAnt = false;
        this.detectChanges();
        setTimeout((/**
         * @return {?}
         */
        () => {
            this._shown = false;
            this.close.emit();
        }), this.config.skin === 'android' ? 200 : 300);
    }
    /**
     * 选择动作
     * @param {?} menu
     * @return {?}
     */
    _onSelect(menu) {
        this.observer.next(menu);
        this.observer.complete();
        this.hide();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.destroied = true;
        if (this.observer && this.observer instanceof Subscription) {
            ((/** @type {?} */ (this.observer))).unsubscribe();
        }
    }
}
ActionSheetComponent.decorators = [
    { type: Component, args: [{
                selector: 'weui-actionsheet',
                exportAs: 'weuiActionsheet',
                template: "<div class=\"weui-mask\" [@visibility]=\"_visibility\" (click)=\"hide(true)\"></div>\n<div class=\"weui-actionsheet\" [ngClass]=\"{ 'weui-actionsheet_toggle': _shownAnt && config.skin === 'ios' }\">\n  <div class=\"weui-actionsheet__title\" *ngIf=\"config.skin === 'ios' && config.title\">\n    <p class=\"weui-actionsheet__title-text\">{{ config.title }}</p>\n  </div>\n  <div class=\"weui-actionsheet__menu\">\n    <div class=\"weui-actionsheet__cell\" *ngFor=\"let item of menus\" (click)=\"_onSelect(item)\">{{ item.text }}</div>\n  </div>\n  <div class=\"weui-actionsheet__action\" *ngIf=\"config.skin === 'ios' && config.cancel\">\n    <div class=\"weui-actionsheet__cell\" (click)=\"hide()\">{{ config.cancel }}</div>\n  </div>\n</div>\n",
                animations: [
                    trigger('visibility', [
                        state('show', style({ opacity: 1 })),
                        state('hide', style({ opacity: 0 })),
                        transition('hide <=> show', [animate(200)]),
                    ]),
                ],
                host: {
                    '[hidden]': '!_shown',
                    '[class.weui-skin_android]': 'config.skin === "android"',
                },
                preserveWhitespaces: false,
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None
            }] }
];
/** @nocollapse */
ActionSheetComponent.ctorParameters = () => [
    { type: ActionSheetConfig },
    { type: ChangeDetectorRef }
];
ActionSheetComponent.propDecorators = {
    config: [{ type: Input }],
    menus: [{ type: Input }],
    close: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ActionSheetService extends BaseService {
    /**
     * @param {?} resolver
     * @param {?} applicationRef
     * @param {?} injector
     * @param {?} doc
     */
    constructor(resolver, applicationRef, injector, doc) {
        super(resolver, applicationRef, injector, doc);
    }
    /**
     * 创建一个弹出式菜单并显示
     *
     * @param {?} menus 菜单内容
     * @param {?=} config 配置性（可选）
     * @return {?} 可订阅来获取结果
     */
    show(menus, config = {}) {
        /** @type {?} */
        const componentRef = this.build(ActionSheetComponent);
        componentRef.instance.menus = menus;
        if (config)
            componentRef.instance.config = config;
        componentRef.instance.close.subscribe((/**
         * @return {?}
         */
        () => {
            setTimeout((/**
             * @return {?}
             */
            () => {
                this.destroy(componentRef);
            }), 100);
        }));
        return componentRef.instance.show();
    }
}
ActionSheetService.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */
ActionSheetService.ctorParameters = () => [
    { type: ComponentFactoryResolver },
    { type: ApplicationRef },
    { type: Injector },
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];
/** @nocollapse */ ActionSheetService.ngInjectableDef = defineInjectable({ factory: function ActionSheetService_Factory() { return new ActionSheetService(inject(ComponentFactoryResolver), inject(ApplicationRef), inject(INJECTOR), inject(DOCUMENT)); }, token: ActionSheetService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ActionSheetModule {
}
ActionSheetModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [ActionSheetComponent],
                exports: [ActionSheetComponent],
                entryComponents: [ActionSheetComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { ActionSheetComponent, ActionSheetConfig, ActionSheetModule, ActionSheetService };
//# sourceMappingURL=ngx-weui-actionsheet.js.map
