import { __decorate, __metadata } from 'tslib';
import { Injectable, defineInjectable, Component, ChangeDetectionStrategy, ViewEncapsulation, ElementRef, Input, NgModule } from '@angular/core';
import { UpdateHostClassService, InputBoolean } from 'ngx-weui/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ButtonConfig {
    constructor() {
        /**
         * 操作场景：primary、default、warn
         */
        this.type = 'primary';
        /**
         * disabled状态，默认：`false`
         */
        this.disabled = false;
        /**
         * 是否加载状态，默认：`false`
         */
        this.loading = false;
        /**
         * 镂空按钮，默认：`false`
         */
        this.plain = false;
        /**
         * 是否小号，默认：`false`
         */
        this.mini = false;
    }
}
ButtonConfig.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */ ButtonConfig.ngInjectableDef = defineInjectable({ factory: function ButtonConfig_Factory() { return new ButtonConfig(); }, token: ButtonConfig, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ButtonComponent {
    /**
     * @param {?} _config
     * @param {?} el
     * @param {?} uhcs
     */
    constructor(_config, el, uhcs) {
        this.el = el;
        this.uhcs = uhcs;
        /**
         * 操作场景：primary、default、warn，默认：`primary`
         */
        this.type = 'primary';
        /**
         * 是否加载状态
         */
        this.loading = false;
        /**
         * 是否小号
         */
        this.mini = false;
        /**
         * 镂空按钮
         */
        this.plain = false;
        /**
         * 行按钮
         */
        this.cell = false;
        /**
         * Block 按钮
         */
        this.block = false;
        /**
         * 禁用状态
         */
        this.disabled = false;
        Object.assign(this, _config);
    }
    /**
     * @private
     * @return {?}
     */
    setClassMap() {
        /** @type {?} */
        const prefixCls = 'weui-btn';
        const { uhcs, el, type, plain, cell, disabled, block, mini, loading } = this;
        /** @type {?} */
        const median = plain ? 'plain' : cell ? 'cell' : '';
        uhcs.updateHostClass(el.nativeElement, {
            [`${prefixCls}`]: !cell,
            [`${prefixCls}_cell`]: cell,
            [`${prefixCls}_disabled`]: !plain && disabled,
            [`${prefixCls}_block`]: block,
            [`${prefixCls}_mini`]: mini,
            [`${prefixCls}_${median}-${type}`]: median,
            [`${prefixCls}_${type}`]: !median,
            [`${prefixCls}_loading`]: loading,
            [`${prefixCls}_plain-disabled`]: plain && disabled,
        });
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.setClassMap();
    }
    /**
     * @return {?}
     */
    ngOnChanges() {
        this.setClassMap();
    }
}
ButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 'weui-button, [weui-button]',
                exportAs: 'weuiButton',
                host: {
                    '[attr.disabled]': 'disabled ? "disabled" : null',
                },
                template: '<i class="weui-loading" *ngIf="loading"></i><ng-content></ng-content>',
                providers: [UpdateHostClassService],
                preserveWhitespaces: false,
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None
            }] }
];
/** @nocollapse */
ButtonComponent.ctorParameters = () => [
    { type: ButtonConfig },
    { type: ElementRef },
    { type: UpdateHostClassService }
];
ButtonComponent.propDecorators = {
    type: [{ type: Input, args: ['weui-type',] }],
    loading: [{ type: Input, args: ['weui-loading',] }],
    mini: [{ type: Input, args: ['weui-mini',] }],
    plain: [{ type: Input, args: ['weui-plain',] }],
    cell: [{ type: Input, args: ['weui-cell',] }],
    block: [{ type: Input, args: ['weui-block',] }],
    disabled: [{ type: Input }]
};
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean)
], ButtonComponent.prototype, "loading", void 0);
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean)
], ButtonComponent.prototype, "mini", void 0);
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean)
], ButtonComponent.prototype, "plain", void 0);
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean)
], ButtonComponent.prototype, "cell", void 0);
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean)
], ButtonComponent.prototype, "block", void 0);
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean)
], ButtonComponent.prototype, "disabled", void 0);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ButtonIconComponent {
}
ButtonIconComponent.decorators = [
    { type: Component, args: [{
                selector: 'weui-button-icon, [weui-button-icon]',
                exportAs: 'weuiButtonIcon',
                host: {
                    '[class.weui-btn_cell__icon]': 'true',
                },
                template: '<ng-content></ng-content>',
                preserveWhitespaces: false,
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ButtonModule {
}
ButtonModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [ButtonComponent, ButtonIconComponent],
                exports: [ButtonComponent, ButtonIconComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { ButtonComponent, ButtonConfig, ButtonIconComponent, ButtonModule };
//# sourceMappingURL=ngx-weui-button.js.map
