import { __decorate, __metadata } from 'tslib';
import { Directive, ElementRef, Input, HostListener, NgModule } from '@angular/core';
import { InputNumber } from 'ngx-weui/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * 单元格滑块
 */
class SwipeDirective {
    /**
     * @param {?} el
     */
    constructor(el) {
        this.el = el;
        this.curX = 0;
        this.opend = false;
        /**
         * 右边滑动宽度（单位：px），默认：`68`
         */
        this.width = 68;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        const el = this.el.nativeElement;
        this.swipeEl = el.querySelector('.weui-cell__bd');
        if (!this.swipeEl)
            this.width = 0;
        else {
            this.setPos(0);
            this.swipeEl.style.transition = 'transform .3s';
        }
    }
    /**
     * @private
     * @param {?} x
     * @return {?}
     */
    setPos(x) {
        this.swipeEl.style.transform = `translateX(-${x}px)`;
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onTouchStart($event) {
        this.curX = ($event.touches[0] || $event.changedTouches[0]).pageX;
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onTouchMove($event) {
        /** @type {?} */
        const touch = $event.touches[0] || $event.changedTouches[0];
        /** @type {?} */
        let newX = this.curX - touch.pageX;
        if (this.opend) {
            newX = newX > 0 ? this.width : this.width - Math.abs(newX);
        }
        else {
            newX = newX > this.width ? this.width : newX;
        }
        this.setPos(newX <= 0 ? 0 : newX);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onTouchEnd($event) {
        /** @type {?} */
        const touch = $event.touches[0] || $event.changedTouches[0];
        /** @type {?} */
        let newX = Math.abs(this.curX - touch.pageX);
        if (newX === 0)
            return;
        if (this.opend)
            newX = this.width - newX;
        // 当移动超过一半都视为打开
        if (newX > 0 && newX > +this.width / 2) {
            this.opend = true;
            this.setPos(this.width);
        }
        else {
            this.opend = false;
            this.setPos(0);
        }
    }
}
SwipeDirective.decorators = [
    { type: Directive, args: [{
                selector: '[weui-swipe]',
                exportAs: 'weuiSwipe',
            },] }
];
/** @nocollapse */
SwipeDirective.ctorParameters = () => [
    { type: ElementRef }
];
SwipeDirective.propDecorators = {
    width: [{ type: Input, args: ['weui-width',] }],
    onTouchStart: [{ type: HostListener, args: ['touchstart', ['$event'],] }],
    onTouchMove: [{ type: HostListener, args: ['touchmove', ['$event'],] }],
    onTouchEnd: [{ type: HostListener, args: ['touchend', ['$event'],] }, { type: HostListener, args: ['touchcancel', ['$event'],] }]
};
__decorate([
    InputNumber(),
    __metadata("design:type", Number)
], SwipeDirective.prototype, "width", void 0);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CellModule {
}
CellModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [SwipeDirective],
                exports: [SwipeDirective],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { CellModule, SwipeDirective };
//# sourceMappingURL=ngx-weui-cell.js.map
