import { DOCUMENT, CommonModule } from '@angular/common';
import { Injectable, Inject, defineInjectable, inject, ComponentFactoryResolver, ApplicationRef, Injector, TemplateRef, Directive, ViewContainerRef, Input, NgModule, RendererFactory2 } from '@angular/core';
import { ɵgetDOM } from '@angular/platform-browser';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LoaderService {
    /**
     * @param {?} doc
     */
    constructor(doc) {
        this.doc = doc;
        this.list = {};
    }
    /**
     * @param {?} paths
     * @return {?}
     */
    load(paths) {
        return new Promise((/**
         * @param {?} resolve
         * @return {?}
         */
        resolve => {
            /** @type {?} */
            const promises = [];
            if (!Array.isArray(paths))
                paths = [paths];
            ((/** @type {?} */ (paths))).forEach((/**
             * @param {?} path
             * @return {?}
             */
            path => {
                if (path.endsWith('.css')) {
                    promises.push(this.loadCss(path));
                }
                else {
                    promises.push(this.loadScript(path));
                }
            }));
            Promise.all(promises)
                .then((/**
             * @return {?}
             */
            () => resolve(true)))
                .catch((/**
             * @return {?}
             */
            () => resolve(false)));
        }));
    }
    /**
     * @param {?} path
     * @return {?}
     */
    loadScript(path) {
        return new Promise((/**
         * @param {?} resolve
         * @return {?}
         */
        resolve => {
            if (this.list[path] === true) {
                resolve((/** @type {?} */ ({
                    path,
                    loaded: true,
                    status: 'Loaded',
                })));
                return;
            }
            this.list[path] = true;
            /** @type {?} */
            const node = this.doc.createElement('script');
            node.type = 'text/javascript';
            node.src = path;
            node.charset = 'utf-8';
            node.defer = true;
            node.onload = (/**
             * @return {?}
             */
            () => {
                resolve((/** @type {?} */ ({
                    path,
                    loaded: true,
                    status: 'Loaded',
                })));
            });
            node.onerror = (/**
             * @return {?}
             */
            () => resolve((/** @type {?} */ ({
                path,
                loaded: false,
                status: 'Loaded',
            }))));
            this.doc.getElementsByTagName('head')[0].appendChild(node);
        }));
    }
    /**
     * @param {?} path
     * @return {?}
     */
    loadCss(path) {
        return new Promise((/**
         * @param {?} resolve
         * @return {?}
         */
        resolve => {
            if (this.list[path] === true) {
                resolve((/** @type {?} */ ({
                    path,
                    loaded: true,
                    status: 'Loaded',
                })));
                return;
            }
            this.list[path] = true;
            /** @type {?} */
            const node = this.doc.createElement('link');
            node.rel = 'stylesheet';
            node.type = 'text/css';
            node.href = path;
            this.doc.getElementsByTagName('head')[0].appendChild(node);
            resolve((/** @type {?} */ ({
                path,
                loaded: true,
                status: 'Loaded',
            })));
        }));
    }
}
LoaderService.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */
LoaderService.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];
/** @nocollapse */ LoaderService.ngInjectableDef = defineInjectable({ factory: function LoaderService_Factory() { return new LoaderService(inject(DOCUMENT)); }, token: LoaderService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class BaseService {
    /**
     * @param {?} resolver
     * @param {?} applicationRef
     * @param {?} injector
     * @param {?} doc
     */
    constructor(resolver, applicationRef, injector, doc) {
        this.resolver = resolver;
        this.applicationRef = applicationRef;
        this.injector = injector;
        this.doc = doc;
        this.list = [];
    }
    /**
     * 销毁
     *
     * @param {?=} component 下标（从0开始或组件引用对象），或不指定时，销毁最新一个
     * @return {?}
     */
    destroy(component) {
        if (typeof component === 'number')
            component = this.list[(/** @type {?} */ (component))];
        if (!component)
            component = this.list.pop();
        if (component)
            ((/** @type {?} */ (component))).destroy();
    }
    /**
     * 销毁所有
     * @return {?}
     */
    destroyAll() {
        for (const component of this.list)
            this.destroy(component);
    }
    /**
     * 动态构建组件
     * @protected
     * @template T
     * @param {?} component
     * @return {?}
     */
    build(component) {
        /** @type {?} */
        const componentFactory = this.resolver.resolveComponentFactory(component);
        /** @type {?} */
        const componentRef = componentFactory.create(this.injector);
        this.list.push(componentRef);
        /** @type {?} */
        const componentRootNode = (/** @type {?} */ (((/** @type {?} */ (componentRef.hostView))).rootNodes[0]));
        this.applicationRef.attachView(componentRef.hostView);
        componentRef.onDestroy((/**
         * @return {?}
         */
        () => {
            this.applicationRef.detachView(componentRef.hostView);
        }));
        this.doc.body.appendChild(componentRootNode);
        return componentRef;
    }
}
/** @nocollapse */
BaseService.ctorParameters = () => [
    { type: ComponentFactoryResolver },
    { type: ApplicationRef },
    { type: Injector },
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * 向上查找父节点
 * @param {?} el
 * @param {?} selector
 * @return {?}
 */
function findParent(el, selector) {
    /** @type {?} */
    let retEl = null;
    while (el) {
        if (el.matches(selector)) {
            retEl = el;
            break;
        }
        el = el.parentElement;
    }
    return retEl;
}
/**
 * 查找并创建
 * @param {?} el
 * @param {?=} selector
 * @param {?=} tagName
 * @param {?=} className
 * @param {?=} cssText
 * @return {?}
 */
function add(el, selector = '.weui-cell__ft', tagName = 'div', className = 'weui-cell__ft', cssText = '') {
    /** @type {?} */
    let ret = el.querySelector(selector);
    if (!ret) {
        ret = document.createElement(tagName);
        ret.className = className;
        if (cssText)
            ret.style.cssText = cssText;
        el.appendChild(ret);
    }
    return ret;
}
/**
 * 移除
 * @param {?} el
 * @param {?} selector
 * @return {?}
 */
function remove(el, selector) {
    if (!el)
        return;
    /** @type {?} */
    const ret = el.querySelector(selector);
    if (ret) {
        el.removeChild(ret);
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * 检查是否安卓系统
 * @return {?}
 */
function isAndroid() {
    return /android (\d+)/.test(ɵgetDOM()
        .getUserAgent()
        .toLowerCase());
}
/**
 * 检查是否IOS系统
 * @return {?}
 */
function isIOS() {
    return /iPad|iPhone|iPod/.test(ɵgetDOM().getUserAgent());
}
/**
 * 检查File是否为图像文件
 * @param {?} file
 * @return {?}
 */
function isImage(file) {
    if (!(file instanceof window.File))
        return false;
    /** @type {?} */
    const type = `|${file.type.slice(file.type.lastIndexOf('/') + 1)}|`;
    return '|jpg|png|jpeg|bmp|gif|'.indexOf(type) !== -1;
}
/**
 * 生成可预览的图像地址
 * @param {?} file
 * @return {?}
 */
function genImageUrl(file) {
    if (isImage(file))
        return window.URL.createObjectURL(file);
    return '';
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @param {?} element
 * @return {?}
 */
function isEmpty(element) {
    /** @type {?} */
    const nodes = element.childNodes;
    for (let i = 0; i < nodes.length; i++) {
        /** @type {?} */
        const node = nodes.item(i);
        if (node.nodeType === 1 && ((/** @type {?} */ (node))).outerHTML.toString().trim().length !== 0) {
            return false;
        }
        else if (node.nodeType === 3 && (/** @type {?} */ (node.textContent)).toString().trim().length !== 0) {
            return false;
        }
    }
    return true;
}
/**
 * @param {?} value
 * @param {?=} allowUndefined
 * @return {?}
 */
function toBoolean(value, allowUndefined = false) {
    return allowUndefined && typeof value === 'undefined' ? undefined : value != null && `${value}` !== 'false';
}
/**
 * Input decorator that handle a prop to do get/set automatically with toBoolean
 * \@example
 * ```typescript
 * \@Input() \@InputBoolean() visible: boolean = false; / \@InputBoolean(null) visible: boolean = false;
 * ```
 * @param {?=} allowUndefined
 * @return {?}
 */
function InputBoolean(allowUndefined = false) {
    return (/**
     * @param {?} target
     * @param {?} name
     * @return {?}
     */
    function InputBooleanPropDecorator(target, name) {
        // Add our own private prop
        /** @type {?} */
        const privatePropName = `$$__${name}`;
        if (Object.prototype.hasOwnProperty.call(target, privatePropName)) {
            console.warn(`The prop "${privatePropName}" is already exist, it will be overrided by InputBoolean decorator.`);
        }
        Object.defineProperty(target, privatePropName, {
            configurable: true,
            writable: true,
        });
        Object.defineProperty(target, name, {
            /**
             * @return {?}
             */
            get() {
                return this[privatePropName]; // tslint:disable-line:no-invalid-this
            },
            /**
             * @param {?} value
             * @return {?}
             */
            set(value) {
                this[privatePropName] = toBoolean(value, allowUndefined); // tslint:disable-line:no-invalid-this
            },
        });
    });
}
/**
 * @param {?} value
 * @param {?=} fallbackValue
 * @return {?}
 */
function toNumber(value, fallbackValue = 0) {
    return !isNaN(parseFloat((/** @type {?} */ (value)))) && !isNaN(Number(value)) ? Number(value) : fallbackValue;
}
/**
 * Input decorator that handle a prop to do get/set automatically with toNumber
 * \@example
 * ```typescript
 * \@Input() \@InputNumber() visible: number = 1; / \@InputNumber(null) visible: number = 2;
 * ```
 * @param {?=} fallback
 * @return {?}
 */
function InputNumber(fallback = 0) {
    return (/**
     * @param {?} target
     * @param {?} name
     * @return {?}
     */
    function InputBooleanPropDecorator(target, name) {
        // Add our own private prop
        /** @type {?} */
        const privatePropName = `$$__${name}`;
        if (Object.prototype.hasOwnProperty.call(target, privatePropName)) {
            console.warn(`The prop "${privatePropName}" is already exist, it will be overrided by InputNumber decorator.`);
        }
        Object.defineProperty(target, privatePropName, {
            configurable: true,
            writable: true,
        });
        Object.defineProperty(target, name, {
            /**
             * @return {?}
             */
            get() {
                return this[privatePropName]; // tslint:disable-line:no-invalid-this
            },
            /**
             * @param {?} value
             * @return {?}
             */
            set(value) {
                this[privatePropName] = toNumber(value, fallback); // tslint:disable-line:no-invalid-this
            },
        });
    });
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class StringTemplateOutletDirective {
    /**
     * @param {?} viewContainer
     * @param {?} defaultTemplate
     */
    constructor(viewContainer, defaultTemplate) {
        this.viewContainer = viewContainer;
        this.defaultTemplate = defaultTemplate;
        this.inputTemplate = null;
        this.inputViewRef = null;
        this.defaultViewRef = null;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set stringTemplateOutlet(value) {
        if (value instanceof TemplateRef) {
            this.isTemplate = true;
            this.inputTemplate = value;
        }
        else {
            this.isTemplate = false;
        }
        this.updateView();
    }
    /**
     * @return {?}
     */
    updateView() {
        if (!this.isTemplate) {
            /** use default template when input is string **/
            if (!this.defaultViewRef) {
                this.viewContainer.clear();
                this.inputViewRef = null;
                if (this.defaultTemplate) {
                    this.defaultViewRef = this.viewContainer.createEmbeddedView(this.defaultTemplate);
                }
            }
        }
        else {
            /** use input template when input is templateRef **/
            if (!this.inputViewRef) {
                this.viewContainer.clear();
                this.defaultViewRef = null;
                if (this.inputTemplate) {
                    this.inputViewRef = this.viewContainer.createEmbeddedView(this.inputTemplate);
                }
            }
        }
    }
}
StringTemplateOutletDirective.decorators = [
    { type: Directive, args: [{
                selector: '[stringTemplateOutlet]',
                exportAs: 'stringTemplateOutlet',
            },] }
];
/** @nocollapse */
StringTemplateOutletDirective.ctorParameters = () => [
    { type: ViewContainerRef },
    { type: TemplateRef }
];
StringTemplateOutletDirective.propDecorators = {
    stringTemplateOutlet: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AddOnModule {
}
AddOnModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                exports: [StringTemplateOutletDirective],
                declarations: [StringTemplateOutletDirective],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class UpdateHostClassService {
    /**
     * @param {?} rendererFactory2
     */
    constructor(rendererFactory2) {
        this.classMap = {};
        this.renderer = rendererFactory2.createRenderer(null, null);
    }
    /**
     * @param {?} el
     * @param {?} classMap
     * @return {?}
     */
    updateHostClass(el, classMap) {
        this.removeClass(el, this.classMap, this.renderer);
        this.classMap = Object.assign({}, classMap);
        this.addClass(el, this.classMap, this.renderer);
    }
    /**
     * @private
     * @param {?} el
     * @param {?} classMap
     * @param {?} renderer
     * @return {?}
     */
    removeClass(el, classMap, renderer) {
        for (const i in classMap) {
            if (classMap.hasOwnProperty(i)) {
                renderer.removeClass(el, i);
            }
        }
    }
    /**
     * @private
     * @param {?} el
     * @param {?} classMap
     * @param {?} renderer
     * @return {?}
     */
    addClass(el, classMap, renderer) {
        for (const i in classMap) {
            if (classMap.hasOwnProperty(i) && classMap[i]) {
                renderer.addClass(el, i);
            }
        }
    }
}
UpdateHostClassService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
UpdateHostClassService.ctorParameters = () => [
    { type: RendererFactory2 }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { AddOnModule, BaseService, InputBoolean, InputNumber, LoaderService, StringTemplateOutletDirective, UpdateHostClassService, add, findParent, genImageUrl, isAndroid, isEmpty, isIOS, isImage, remove, toBoolean, toNumber };
//# sourceMappingURL=ngx-weui-core.js.map
