import { Injectable, defineInjectable, EventEmitter, Component, ChangeDetectionStrategy, ViewEncapsulation, ElementRef, Input, Output, NgModule } from '@angular/core';
import { fromEvent } from 'rxjs';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class InfiniteLoaderConfig {
    constructor() {
        /**
         * 容器高度，默认：`100vh`
         */
        this.height = '100vh';
        /**
         * 滚动至x%时触发加载，默认：75%
         */
        this.percent = 75;
        /**
         * 加载中文本（支持HTML），默认：weui-loadmore 组件
         */
        this.loading = '<div class="weui-loadmore"><i class="weui-loading"></i><span class="weui-loadmore__tips">加载中…</span></div>';
        /**
         * 完成所有数据加载文本（支持HTML），默认：weui-loadmore 组件
         */
        this.finished = '<div class="weui-loadmore weui-loadmore_line"><span class="weui-loadmore__tips">已加载完毕</span></div>';
        /**
         * 滚动节流时长（单位：ms），默认：`100`
         */
        this.throttle = 100;
    }
}
InfiniteLoaderConfig.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */ InfiniteLoaderConfig.ngInjectableDef = defineInjectable({ factory: function InfiniteLoaderConfig_Factory() { return new InfiniteLoaderConfig(); }, token: InfiniteLoaderConfig, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class InfiniteLoaderComponent {
    /**
     * @param {?} el
     * @param {?} DEF
     */
    constructor(el, DEF) {
        this.el = el;
        this.DEF = DEF;
        this.didScroll = false;
        this.scrollEvent = null;
        this.scrollTime = null;
        this._loading = false;
        this._finished = false;
        this.loadmore = new EventEmitter();
        this.config = Object.assign({}, DEF);
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set config(val) {
        this._config = Object.assign({}, this.DEF, val);
    }
    /**
     * @return {?}
     */
    get config() {
        return this._config;
    }
    /**
     * 设置本次加载完成
     * @return {?}
     */
    resolveLoading() {
        this._loading = false;
        this._finished = false;
    }
    /**
     * 设置结束
     * @return {?}
     */
    setFinished() {
        this._loading = false;
        this._finished = true;
    }
    /**
     * 设置重新开始
     * @return {?}
     */
    restart() {
        this._finished = false;
    }
    /**
     * @return {?}
     */
    _onScroll() {
        if (this._loading || this._finished)
            return;
        /** @type {?} */
        const target = this.scrollEvent.target;
        /** @type {?} */
        const scrollPercent = Math.floor(((target.scrollTop + target.clientHeight) / target.scrollHeight) * 100);
        if (scrollPercent > (/** @type {?} */ (this.config.percent))) {
            this._loading = true;
            this.loadmore.emit(this);
        }
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.scrollTime = setInterval((/**
         * @return {?}
         */
        () => {
            if (this.didScroll) {
                this.didScroll = false;
                this._onScroll();
            }
        }), this.config.throttle);
        this.disposeScroller = fromEvent((/** @type {?} */ (this.el.nativeElement.querySelector('.weui-infiniteloader__content'))), 'scroll').subscribe((/**
         * @param {?} $event
         * @return {?}
         */
        ($event) => {
            this.scrollEvent = $event;
            this.didScroll = true;
        }));
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.scrollTime)
            clearTimeout(this.scrollTime);
        if (this.disposeScroller)
            this.disposeScroller.unsubscribe();
    }
}
InfiniteLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'weui-infiniteloader',
                exportAs: 'weuiInfiniteloader',
                template: "<div class=\"weui-infiniteloader__content\">\n  <ng-content></ng-content>\n  <div *ngIf=\"_loading || _finished\">\n    <div *ngIf=\"_loading\" [innerHTML]=\"config.loading\"></div>\n    <div *ngIf=\"_finished\" [innerHTML]=\"config.finished\"></div>\n  </div>\n</div>\n",
                host: {
                    '[class.weui-infiniteloader]': 'true',
                    '[style.height]': 'config.height',
                },
                preserveWhitespaces: false,
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None
            }] }
];
/** @nocollapse */
InfiniteLoaderComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: InfiniteLoaderConfig }
];
InfiniteLoaderComponent.propDecorators = {
    config: [{ type: Input }],
    loadmore: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class InfiniteLoaderModule {
}
InfiniteLoaderModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [InfiniteLoaderComponent],
                exports: [InfiniteLoaderComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { InfiniteLoaderComponent, InfiniteLoaderConfig, InfiniteLoaderModule };
//# sourceMappingURL=ngx-weui-infiniteloader.js.map
