import { Injectable, defineInjectable, EventEmitter, Component, ChangeDetectionStrategy, ViewEncapsulation, Input, Output, NgModule } from '@angular/core';
import { __decorate, __metadata } from 'tslib';
import { InputNumber, InputBoolean } from 'ngx-weui/core';
import { CommonModule } from '@angular/common';
import { ButtonModule } from 'ngx-weui/button';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PaginationConfig {
    constructor() {
        /**
         * 形态，可选 `button`,`pointer`，默认：`button`
         */
        this.mode = 'button';
        /**
         * 是否隐藏数值，默认：`false`
         */
        this.simple = false;
        /**
         * 小号按钮，默认：`true`
         */
        this.mini = true;
        /**
         * 上一页文本（支持HTML），默认：`上一页`
         */
        this.prevText = '上一页';
        /**
         * 下一页文本（支持HTML），默认：`下一步`
         */
        this.nextText = '下一步';
    }
}
PaginationConfig.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */ PaginationConfig.ngInjectableDef = defineInjectable({ factory: function PaginationConfig_Factory() { return new PaginationConfig(); }, token: PaginationConfig, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PaginationComponent {
    /**
     * @param {?} cog
     */
    constructor(cog) {
        this._ptArr = [];
        this._prevDisabled = false;
        this._nextDisabled = false;
        /**
         * 当前索引
         */
        this.current = 0;
        /**
         * 数据总数
         */
        this.total = 0;
        /**
         * 小号按钮，默认：`true`
         */
        this.mini = true;
        /**
         * 分页触发的回调函数
         */
        this.change = new EventEmitter();
        Object.assign(this, cog);
    }
    /**
     * @return {?}
     */
    ngOnChanges() {
        if (this.mode === 'pointer')
            this._ptArr = Array(this.total)
                .fill(1)
                .map((/**
             * @param {?} v
             * @param {?} i
             * @return {?}
             */
            (v, i) => v + i));
        this._checkDisabled();
    }
    /**
     * @return {?}
     */
    _checkDisabled() {
        if (this.mode === 'pointer')
            return;
        this._prevDisabled = this.current <= 1;
        this._nextDisabled = this.current >= this.total;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    _goto(value) {
        if (value === -1 && this._prevDisabled)
            return false;
        if (value === 1 && this._nextDisabled)
            return false;
        this.current += value;
        this._checkDisabled();
        this.change.emit(this.current);
    }
}
PaginationComponent.decorators = [
    { type: Component, args: [{
                selector: 'weui-pagination',
                exportAs: 'weuiPagination',
                template: "<ng-template [ngIf]=\"mode === 'button'\">\n  <div class=\"weui-pagination__item weui-pagination__prev\">\n    <a\n      weui-button\n      (click)=\"_goto(-1)\"\n      weui-plain\n      [weui-mini]=\"mini\"\n      weui-type=\"default\"\n      [disabled]=\"_prevDisabled\"\n      [innerHTML]=\"prevText\"\n    ></a>\n  </div>\n  <div class=\"weui-pagination__item weui-pagination__num\" *ngIf=\"!simple\">{{ current }}/{{ total }}</div>\n  <div class=\"weui-pagination__item weui-pagination__next\">\n    <a\n      weui-button\n      (click)=\"_goto(1)\"\n      weui-plain\n      [weui-mini]=\"mini\"\n      weui-type=\"default\"\n      [disabled]=\"_nextDisabled\"\n      [innerHTML]=\"nextText\"\n    ></a>\n  </div>\n</ng-template>\n<div class=\"weui-pagination__item weui-pagination__num\" *ngIf=\"mode === 'pointer'\">\n  <div *ngFor=\"let i of _ptArr\" class=\"weui-pagination__dot\" [class.weui-pagination__dot-active]=\"current === i\">\n    <span></span>\n  </div>\n</div>\n",
                host: {
                    class: 'weui-pagination',
                    '[class.weui-pagination__non-mini]': '!mini',
                },
                preserveWhitespaces: false,
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None
            }] }
];
/** @nocollapse */
PaginationComponent.ctorParameters = () => [
    { type: PaginationConfig }
];
PaginationComponent.propDecorators = {
    mode: [{ type: Input }],
    current: [{ type: Input }],
    total: [{ type: Input }],
    simple: [{ type: Input }],
    mini: [{ type: Input }],
    prevText: [{ type: Input }],
    nextText: [{ type: Input }],
    change: [{ type: Output }]
};
__decorate([
    InputNumber(),
    __metadata("design:type", Number)
], PaginationComponent.prototype, "current", void 0);
__decorate([
    InputNumber(),
    __metadata("design:type", Number)
], PaginationComponent.prototype, "total", void 0);
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean)
], PaginationComponent.prototype, "simple", void 0);
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean)
], PaginationComponent.prototype, "mini", void 0);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PaginationModule {
}
PaginationModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, ButtonModule],
                declarations: [PaginationComponent],
                exports: [PaginationComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { PaginationComponent, PaginationConfig, PaginationModule };
//# sourceMappingURL=ngx-weui-pagination.js.map
