import { DOCUMENT, CommonModule } from '@angular/common';
import { Injectable, defineInjectable, EventEmitter, Component, ChangeDetectionStrategy, ViewEncapsulation, Input, Output, ComponentFactoryResolver, ApplicationRef, Injector, Inject, inject, INJECTOR, NgModule } from '@angular/core';
import { InputNumber, BaseService } from 'ngx-weui/core';
import { __decorate, __metadata } from 'tslib';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ToastConfig {
    constructor() {
        /**
         * 成功配置项
         */
        this.success = {
            text: '已完成',
            icon: 'weui-icon-success-no-circle',
            time: 2000,
        };
        /**
         * 加载中配置项
         */
        this.loading = {
            text: '加载中…',
            icon: 'weui-loading',
            time: 2000,
        };
    }
}
ToastConfig.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */ ToastConfig.ngInjectableDef = defineInjectable({ factory: function ToastConfig_Factory() { return new ToastConfig(); }, token: ToastConfig, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ToastComponent {
    /**
     * @param {?} DEF
     */
    constructor(DEF) {
        this.DEF = DEF;
        /**
         * 显示时长后自动关闭（单位：ms），0 表示永久，默认：`2000`
         */
        this.time = 2000;
        /**
         * 隐藏后回调
         */
        this.hide = new EventEmitter();
        this._showd = false;
        this.type = 'success';
    }
    /**
     * 类型
     * @param {?} _t
     * @return {?}
     */
    set type(_t) {
        Object.assign(this, this.DEF[_t]);
    }
    /**
     * @template THIS
     * @this {THIS}
     * @return {THIS}
     */
    onShow() {
        (/** @type {?} */ (this))._showd = true;
        if ((/** @type {?} */ (this)).time > 0) {
            (/** @type {?} */ (this)).timer = setTimeout((/**
             * @return {?}
             */
            () => {
                (/** @type {?} */ (this)).onHide();
            }), (/** @type {?} */ (this)).time);
        }
        return (/** @type {?} */ (this));
    }
    /**
     * @return {?}
     */
    onHide() {
        this._showd = false;
        this.hide.emit();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.timer) {
            clearTimeout(this.timer);
            this.timer = null;
        }
    }
}
ToastComponent.decorators = [
    { type: Component, args: [{
                selector: 'weui-toast',
                exportAs: 'weuiToast',
                template: "<div class=\"weui-mask_transparent\"></div>\n<div class=\"weui-toast\">\n  <i class=\"{{ icon }} weui-icon_toast\"></i>\n  <p class=\"weui-toast__content\">{{ text }}</p>\n</div>\n",
                host: {
                    '[hidden]': '!_showd',
                },
                preserveWhitespaces: false,
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None
            }] }
];
/** @nocollapse */
ToastComponent.ctorParameters = () => [
    { type: ToastConfig }
];
ToastComponent.propDecorators = {
    type: [{ type: Input }],
    text: [{ type: Input }],
    icon: [{ type: Input }],
    time: [{ type: Input }],
    hide: [{ type: Output }]
};
__decorate([
    InputNumber(),
    __metadata("design:type", Number)
], ToastComponent.prototype, "time", void 0);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ToastService extends BaseService {
    /**
     * @param {?} resolver
     * @param {?} applicationRef
     * @param {?} injector
     * @param {?} doc
     */
    constructor(resolver, applicationRef, injector, doc) {
        super(resolver, applicationRef, injector, doc);
    }
    /**
     * 构建toast并显示
     *
     * @param {?=} text
     * @param {?=} time
     * @param {?=} icon
     * @param {?=} type
     * @return {?}
     */
    show(text, time, icon, type) {
        /** @type {?} */
        const componentRef = this.build(ToastComponent);
        if (type)
            componentRef.instance.type = type;
        if (text)
            componentRef.instance.text = text;
        if (icon)
            componentRef.instance.icon = icon;
        if (typeof time === 'number')
            componentRef.instance.time = time;
        componentRef.instance.hide.subscribe((/**
         * @return {?}
         */
        () => {
            setTimeout((/**
             * @return {?}
             */
            () => {
                componentRef.destroy();
            }), 300);
        }));
        return componentRef.instance.onShow();
    }
    /**
     * 关闭最新toast
     * @return {?}
     */
    hide() {
        this.destroy();
    }
    /**
     * 构建成功toast并显示
     *
     * @param {?=} text
     * @param {?=} time
     * @param {?=} icon
     * @return {?}
     */
    success(text, time, icon) {
        return this.show(text, time, icon, 'success');
    }
    /**
     * 构建加载中toast并显示
     *
     * @param {?=} text
     * @param {?=} time
     * @param {?=} icon
     * @return {?}
     */
    loading(text, time, icon) {
        return this.show(text, time, icon, 'loading');
    }
}
ToastService.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */
ToastService.ctorParameters = () => [
    { type: ComponentFactoryResolver },
    { type: ApplicationRef },
    { type: Injector },
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];
/** @nocollapse */ ToastService.ngInjectableDef = defineInjectable({ factory: function ToastService_Factory() { return new ToastService(inject(ComponentFactoryResolver), inject(ApplicationRef), inject(INJECTOR), inject(DOCUMENT)); }, token: ToastService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ToastModule {
}
ToastModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [ToastComponent],
                exports: [ToastComponent],
                entryComponents: [ToastComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { ToastComponent, ToastConfig, ToastModule, ToastService };
//# sourceMappingURL=ngx-weui-toast.js.map
