import { __decorate, __metadata } from 'tslib';
import { defineInjectable, Injectable, Component, ChangeDetectionStrategy, ViewEncapsulation, Input, Output, EventEmitter, Inject, NgModule } from '@angular/core';
import { InputBoolean } from 'ngx-weui/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var AccordionConfig = /** @class */ (function () {
    function AccordionConfig() {
        /**
         * 是否可折叠，`false` 表示保持只有一个可折叠，`true` 表示所有都允许，默认：`false`
         */
        this.collapsible = false;
        /**
         * 自动展开第一次，默认：`true`
         */
        this.activeFirst = true;
        /**
         * 动画类型，`none` 无动画，`slide` 滑动，默认：`slide`
         */
        this.animate = 'slide';
    }
    AccordionConfig.decorators = [
        { type: Injectable, args: [{ providedIn: 'root' },] }
    ];
    /** @nocollapse */ AccordionConfig.ngInjectableDef = defineInjectable({ factory: function AccordionConfig_Factory() { return new AccordionConfig(); }, token: AccordionConfig, providedIn: "root" });
    return AccordionConfig;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var AccordionComponent = /** @class */ (function () {
    function AccordionComponent(config) {
        /**
         * 是否可折叠，`true` 表示同时所有都允许展开，`false` 表示同时只允许一个展开，默认：`false`
         */
        this.collapsible = false;
        /**
         * 自动展开第一次，默认：`true`
         */
        this.activeFirst = true;
        /**
         * 动画类型，`none` 无动画，`slide` 滑动，默认：`slide`
         */
        this._animate = 'slide';
        /**
         * 展开时回调，参数为面板下标。
         */
        this.select = new EventEmitter();
        this.panels = [];
        Object.assign(this, config);
    }
    /**
     * @param {?} item
     * @return {?}
     */
    AccordionComponent.prototype._add = /**
     * @param {?} item
     * @return {?}
     */
    function (item) {
        this.panels.push(item);
        if (this.panels.length === 1 && this.activeFirst)
            item.active = true;
    };
    /**
     * @param {?} item
     * @return {?}
     */
    AccordionComponent.prototype._remove = /**
     * @param {?} item
     * @return {?}
     */
    function (item) {
        this.panels.splice(this.panels.indexOf(item), 1);
    };
    /**
     * @param {?} item
     * @return {?}
     */
    AccordionComponent.prototype._index = /**
     * @param {?} item
     * @return {?}
     */
    function (item) {
        return this.panels.indexOf(item);
    };
    /**
     * @param {?} cur
     * @return {?}
     */
    AccordionComponent.prototype._closeOthers = /**
     * @param {?} cur
     * @return {?}
     */
    function (cur) {
        if (this.collapsible)
            return;
        this.panels.forEach((/**
         * @param {?} panel
         * @return {?}
         */
        function (panel) {
            if (!panel.disabled && panel !== cur)
                panel.active = false;
        }));
    };
    AccordionComponent.decorators = [
        { type: Component, args: [{
                    selector: 'weui-accordion',
                    exportAs: 'weuiAccordion',
                    template: "\n    <ng-content></ng-content>\n  ",
                    host: {
                        '[attr.aria-multiselectable]': 'closeOthers',
                    },
                    preserveWhitespaces: false,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None
                }] }
    ];
    /** @nocollapse */
    AccordionComponent.ctorParameters = function () { return [
        { type: AccordionConfig }
    ]; };
    AccordionComponent.propDecorators = {
        collapsible: [{ type: Input }],
        activeFirst: [{ type: Input }],
        _animate: [{ type: Input }],
        select: [{ type: Output }]
    };
    __decorate([
        InputBoolean(),
        __metadata("design:type", Boolean)
    ], AccordionComponent.prototype, "collapsible", void 0);
    __decorate([
        InputBoolean(),
        __metadata("design:type", Boolean)
    ], AccordionComponent.prototype, "activeFirst", void 0);
    return AccordionComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var AccordionPanelComponent = /** @class */ (function () {
    function AccordionPanelComponent(accordion) {
        this.accordion = accordion;
        /**
         * 是否禁止
         */
        this.disabled = false;
        this._active = false;
    }
    Object.defineProperty(AccordionPanelComponent.prototype, "active", {
        /**
         * 是否展开
         */
        get: /**
         * 是否展开
         * @return {?}
         */
        function () {
            return this._active;
        },
        set: /**
         * @param {?} value
         * @return {?}
         */
        function (value) {
            this._active = value;
            if (value)
                this.accordion._closeOthers(this);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    AccordionPanelComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        this.accordion._add(this);
    };
    /**
     * @return {?}
     */
    AccordionPanelComponent.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        this.accordion._remove(this);
    };
    /**
     * @return {?}
     */
    AccordionPanelComponent.prototype._toggle = /**
     * @return {?}
     */
    function () {
        if (!this.disabled) {
            this.active = !this.active;
            this.accordion.select.emit(this.accordion._index(this));
        }
    };
    AccordionPanelComponent.decorators = [
        { type: Component, args: [{
                    selector: 'weui-accordion-panel',
                    exportAs: 'weuiAccordionPanel',
                    template: "\n    <div role=\"tab\" (click)=\"_toggle()\"><ng-content select=\"[heading]\"></ng-content></div>\n    <div role=\"tabpanel\" class=\"weui-accordion-content\"><ng-content></ng-content></div>\n  ",
                    host: {
                        '[class.weui-accordion-panel-disabled]': 'disabled',
                        '[class.weui-accordion-active]': 'active',
                    },
                    preserveWhitespaces: false,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None
                }] }
    ];
    /** @nocollapse */
    AccordionPanelComponent.ctorParameters = function () { return [
        { type: AccordionComponent, decorators: [{ type: Inject, args: [AccordionComponent,] }] }
    ]; };
    AccordionPanelComponent.propDecorators = {
        disabled: [{ type: Input }],
        active: [{ type: Input }]
    };
    __decorate([
        InputBoolean(),
        __metadata("design:type", Boolean)
    ], AccordionPanelComponent.prototype, "disabled", void 0);
    __decorate([
        InputBoolean(),
        __metadata("design:type", Boolean),
        __metadata("design:paramtypes", [Boolean])
    ], AccordionPanelComponent.prototype, "active", null);
    return AccordionPanelComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var AccordionModule = /** @class */ (function () {
    function AccordionModule() {
    }
    AccordionModule.decorators = [
        { type: NgModule, args: [{
                    imports: [CommonModule],
                    declarations: [AccordionPanelComponent, AccordionComponent],
                    exports: [AccordionPanelComponent, AccordionComponent],
                },] }
    ];
    return AccordionModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { AccordionComponent, AccordionConfig, AccordionModule, AccordionPanelComponent };
//# sourceMappingURL=ngx-weui-accordion.js.map
