import { __assign, __extends } from 'tslib';
import { DOCUMENT, CommonModule } from '@angular/common';
import { defineInjectable, Injectable, Component, ChangeDetectionStrategy, ViewEncapsulation, ChangeDetectorRef, Input, Output, ViewChild, EventEmitter, ComponentFactoryResolver, ApplicationRef, Injector, Inject, inject, INJECTOR, NgModule } from '@angular/core';
import { isAndroid, BaseService } from 'ngx-weui/core';
import { Observable, Subscription } from 'rxjs';
import { FormsModule } from '@angular/forms';
import { FormModule } from 'ngx-weui/form';
import { MaskModule } from 'ngx-weui/mask';
import { SliderModule } from 'ngx-weui/slider';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var DialogConfig = /** @class */ (function () {
    function DialogConfig() {
        /**
         * 对话框类型，默认：`default`
         * default：默认文本或HTML格式
         * prompt：可输入对话框
         */
        this.type = 'default';
        /**
         * 样式，默认：`auto`
         */
        this.skin = 'auto';
        /**
         * 取消，返回false，默认：`取消`
         */
        this.cancel = '取消';
        /**
         * 取消按钮类型，默认：`default`
         */
        this.cancelType = 'default';
        /**
         * 确认，返回true，默认：`确认`
         */
        this.confirm = '确认';
        /**
         * 确认按钮类型，默认：`primary`
         */
        this.confirmType = 'primary';
        /**
         * 允许点击背景关闭，默认：`false`
         */
        this.backdrop = false;
    }
    DialogConfig.decorators = [
        { type: Injectable, args: [{ providedIn: 'root' },] }
    ];
    /** @nocollapse */ DialogConfig.ngInjectableDef = defineInjectable({ factory: function DialogConfig_Factory() { return new DialogConfig(); }, token: DialogConfig, providedIn: "root" });
    return DialogConfig;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * 对话框，依赖于 `weui-textarea`、`weui-slider`
 *
 * 关于 `input==='prompt'` 若干细节：
 *  + 对话框内放表单在weui的表现并不是很如意，因此，在对话框增加 `.weui-dialog__prompt` 样式类名，请自行针对性进行一些样式的覆盖，`ngx-dialog` 不提供任何样式的修正。
 *  + 对于录入型表单其校验机制全都是依赖于正则，默认情况下内置 `email`、`url` 两种表单类型的正则。
 */
var DialogComponent = /** @class */ (function () {
    function DialogComponent(DEF, cdr) {
        this.DEF = DEF;
        this.cdr = cdr;
        this._shown = false;
        /**
         * 打开动画结束后回调（唯一参数：对话框实例对象）
         */
        this.open = new EventEmitter();
        /**
         * 关闭动画开始时回调（唯一参数：对话框实例对象）
         */
        this.close = new EventEmitter();
        this._prompError = false;
    }
    Object.defineProperty(DialogComponent.prototype, "config", {
        get: /**
         * @return {?}
         */
        function () {
            return this._config;
        },
        /**
         * 对话框配置项
         */
        set: /**
         * 对话框配置项
         * @param {?} value
         * @return {?}
         */
        function (value) {
            var _this = this;
            /** @type {?} */
            var config = __assign({ backdrop: false }, this.DEF, value);
            if (config.skin === 'auto') {
                config.skin = isAndroid() ? 'android' : 'ios';
            }
            // 重组btns
            if (!config.btns) {
                config.btns = [];
                if (config.cancel) {
                    config.btns.push({
                        text: config.cancel,
                        type: (/** @type {?} */ (config.cancelType)),
                        value: false,
                    });
                }
                if (config.confirm) {
                    config.btns.push({
                        text: config.confirm,
                        type: (/** @type {?} */ (config.confirmType)),
                        value: true,
                    });
                }
            }
            // prompt
            if (config.type === 'prompt') {
                // 一些默认校验正则表达式
                if (!config.inputRegex) {
                    switch (config.input) {
                        case 'email':
                            config.inputRegex = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
                            if (!config.inputError)
                                config.inputError = '邮箱格式不正确';
                            break;
                        case 'url':
                            config.inputRegex = /^(https?:\/\/)?([\da-z\.-]+)\.([a-z\.]{2,6})([\/\w \.-]*)*\/?$/;
                            if (!config.inputError)
                                config.inputError = '网址格式不正确';
                            break;
                    }
                }
                config.inputOptions = (/** @type {?} */ ((config.inputOptions || []))).slice(0);
                config.inputAttributes = __assign({ maxlength: null, min: 0, max: 100, step: 1 }, config.inputAttributes);
                // 默认值
                /** @type {?} */
                var defaultValue = config.inputValue;
                if (config.input === 'checkbox' && !Array.isArray(config.inputValue)) {
                    defaultValue = typeof defaultValue !== 'undefined' ? [defaultValue] : [];
                }
                config.inputValue = defaultValue || '';
                this._promptData = config.inputValue;
                if (this._promptData) {
                    this._config = config;
                    this.promptCheck();
                }
                setTimeout((/**
                 * @return {?}
                 */
                function () {
                    _this.setFocus();
                }), 100);
            }
            this._config = config;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @private
     * @return {?}
     */
    DialogComponent.prototype.promptCheck = /**
     * @private
     * @return {?}
     */
    function () {
        if (this.config.inputRequired === true) {
            if (this.config.input === 'checkbox' && this._promptData.length === 0) {
                this._prompError = true;
                return false;
            }
            if (!this._promptData) {
                this._prompError = true;
                return false;
            }
        }
        if (this.config.inputRegex && !this.config.inputRegex.test(this._promptData.toString())) {
            this._prompError = true;
            return false;
        }
        this._prompError = false;
        return true;
    };
    /**
     * @private
     * @return {?}
     */
    DialogComponent.prototype.setFocus = /**
     * @private
     * @return {?}
     */
    function () {
        /** @type {?} */
        var containerEl = this.container.nativeElement;
        /** @type {?} */
        var firstFormEl = null;
        if (this.config.type === 'prompt') {
            firstFormEl = containerEl.querySelector('input, textarea, select');
        }
        else {
            firstFormEl = containerEl.querySelector('.weui-dialog__btn_primary');
        }
        if (firstFormEl)
            firstFormEl.focus();
    };
    /**
     * @return {?}
     */
    DialogComponent.prototype._chanage = /**
     * @return {?}
     */
    function () {
        this.promptCheck();
    };
    /**
     * @param {?} event
     * @return {?}
     */
    DialogComponent.prototype._keyup = /**
     * @param {?} event
     * @return {?}
     */
    function (event) {
        // tslint:disable-next-line: deprecation
        if (event.keyCode === 13) {
            this._onSelect();
        }
    };
    /**
     * 显示，组件载入页面后并不会显示，显示调用 `show()` 并订阅结果。
     *
     * @returns 当 `type==='prompt'` 时会多一 `result` 属性表示结果值
     */
    /**
     * 显示，组件载入页面后并不会显示，显示调用 `show()` 并订阅结果。
     *
     * @return {?} 当 `type==='prompt'` 时会多一 `result` 属性表示结果值
     */
    DialogComponent.prototype.show = /**
     * 显示，组件载入页面后并不会显示，显示调用 `show()` 并订阅结果。
     *
     * @return {?} 当 `type==='prompt'` 时会多一 `result` 属性表示结果值
     */
    function () {
        var _this = this;
        this._shown = true;
        this._prompError = false;
        this.cdr.detectChanges();
        // 模拟动画结束后回调
        setTimeout((/**
         * @return {?}
         */
        function () {
            _this.open.emit(_this);
        }), 300);
        return Observable.create((/**
         * @param {?} observer
         * @return {?}
         */
        function (observer) {
            _this.observer = observer;
        }));
    };
    /**
     * 隐藏
     *
     * @param is_backdrop 是否从背景上点击
     */
    /**
     * 隐藏
     *
     * @param {?=} is_backdrop 是否从背景上点击
     * @return {?}
     */
    DialogComponent.prototype.hide = /**
     * 隐藏
     *
     * @param {?=} is_backdrop 是否从背景上点击
     * @return {?}
     */
    function (is_backdrop) {
        if (is_backdrop === void 0) { is_backdrop = false; }
        if (is_backdrop === true && this.config.backdrop === false)
            return false;
        this._shown = false;
        this.cdr.detectChanges();
        this.close.emit(this);
    };
    /**
     * @param {?=} menu
     * @return {?}
     */
    DialogComponent.prototype._onSelect = /**
     * @param {?=} menu
     * @return {?}
     */
    function (menu) {
        // 未指定时查找 `value===true` 的按钮
        if (!menu && (/** @type {?} */ (this.config.btns)).length > 0) {
            menu = (/** @type {?} */ (this.config.btns)).find((/**
             * @param {?} w
             * @return {?}
             */
            function (w) { return w.value === true; }));
        }
        /** @type {?} */
        var ret = menu;
        if (menu.value === true && this._config.type === 'prompt') {
            if (!this.promptCheck())
                return false;
            ret.result = this._promptData;
        }
        this.observer.next(ret);
        this.observer.complete();
        this.hide();
        return false;
    };
    /**
     * @return {?}
     */
    DialogComponent.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        if (this.observer && this.observer instanceof Subscription) {
            ((/** @type {?} */ (this.observer))).unsubscribe();
        }
    };
    DialogComponent.decorators = [
        { type: Component, args: [{
                    selector: 'weui-dialog',
                    exportAs: 'weuiDialog',
                    template: "<div class=\"weui-mask\" [ngClass]=\"{ 'weui-mask__in': _shown }\" (click)=\"hide(true)\"></div>\n<div\n  class=\"weui-dialog\"\n  [ngClass]=\"{\n    'weui-dialog__in': _shown,\n    'weui-skin_android': config.skin === 'android',\n    'weui-dialog__prompt': config.type === 'prompt'\n  }\"\n  #container\n>\n  <div class=\"weui-dialog__hd\" *ngIf=\"config.title\">\n    <strong class=\"weui-dialog__title\">{{ config.title }}</strong>\n  </div>\n  <div class=\"weui-dialog__bd\" *ngIf=\"config.content\" [innerHTML]=\"config.content\"></div>\n  <div class=\"weui-cells\" *ngIf=\"config.type === 'prompt' && _shown\">\n    <ng-container [ngSwitch]=\"config.input\">\n      <div *ngSwitchCase=\"'textarea'\" class=\"weui-cell\" [ngClass]=\"{ 'weui-cell_warn': _prompError }\">\n        <div class=\"weui-cell__bd\">\n          <textarea\n            class=\"weui-textarea\"\n            placeholder=\"{{ config.inputPlaceholder }}\"\n            [(ngModel)]=\"_promptData\"\n            name=\"_promptData\"\n            (ngModelChange)=\"_chanage()\"\n            weui-textarea\n            weui-cn=\"{{ config.inputAttributes.cn }}\"\n            [maxlength]=\"config.inputAttributes.maxlength\"\n          ></textarea>\n        </div>\n      </div>\n      <div *ngSwitchCase=\"'select'\" class=\"weui-cell weui-cell_select\">\n        <div class=\"weui-cell__bd\">\n          <select class=\"weui-select\" [(ngModel)]=\"_promptData\" name=\"_promptData\" (ngModelChange)=\"_chanage()\">\n            <option *ngFor=\"let i of config.inputOptions\" [ngValue]=\"i\">{{ i.text }}</option>\n          </select>\n        </div>\n      </div>\n      <div *ngSwitchCase=\"'radio'\" class=\"weui-cells_radio\">\n        <label class=\"weui-cell weui-check__label\" *ngFor=\"let i of config.inputOptions\">\n          <div class=\"weui-cell__bd\">\n            <p>{{ i.text }}</p>\n          </div>\n          <div class=\"weui-cell__ft\">\n            <input\n              type=\"radio\"\n              (click)=\"_promptData = i\"\n              [checked]=\"i == _promptData\"\n              (change)=\"_chanage()\"\n              class=\"weui-check\"\n            />\n            <span class=\"weui-icon-checked\"></span>\n          </div>\n        </label>\n      </div>\n      <div *ngSwitchCase=\"'checkbox'\" class=\"weui-cells_checkbox\">\n        <label class=\"weui-cell weui-check__label\" *ngFor=\"let i of config.inputOptions\">\n          <div class=\"weui-cell__hd\">\n            <input\n              type=\"checkbox\"\n              class=\"weui-check\"\n              (change)=\"_chanage()\"\n              [weui-checklist]=\"_promptData\"\n              [weui-value]=\"i\"\n              name=\"_promptData\"\n            />\n            <i class=\"weui-icon-checked\"></i>\n          </div>\n          <div class=\"weui-cell__bd\">\n            <p>{{ i.text }}</p>\n          </div>\n        </label>\n      </div>\n      <div\n        *ngSwitchCase=\"'range'\"\n        class=\"weui-slider-box\"\n        [(ngModel)]=\"_promptData\"\n        name=\"_promptData\"\n        weui-slider\n        weui-min=\"{{ config.inputAttributes.min }}\"\n        weui-max=\"{{ config.inputAttributes.max }}\"\n        weui-step=\"{{ config.inputAttributes.step }}\"\n      >\n        <div class=\"weui-slider\">\n          <div class=\"weui-slider__inner\">\n            <div class=\"weui-slider__track\"></div>\n            <div class=\"weui-slider__handler\"></div>\n          </div>\n        </div>\n        <div class=\"weui-slider-box__value\">{{ _promptData }}</div>\n      </div>\n      <div *ngSwitchDefault class=\"weui-cell\" [ngClass]=\"{ 'weui-cell_warn': _prompError }\">\n        <div class=\"weui-cell__bd\">\n          <input\n            type=\"{{ config.input }}\"\n            class=\"weui-input\"\n            placeholder=\"{{ config.inputPlaceholder }}\"\n            [(ngModel)]=\"_promptData\"\n            name=\"_promptData\"\n            [maxlength]=\"config.inputAttributes.maxlength\"\n            (ngModelChange)=\"_chanage()\"\n            (keyup)=\"_keyup($event)\"\n          />\n        </div>\n        <div class=\"weui-cell__ft\">\n          <i class=\"weui-icon-warn\" *ngIf=\"_prompError\"></i>\n        </div>\n      </div>\n    </ng-container>\n  </div>\n  <div class=\"weui-dialog__error\" *ngIf=\"_prompError\">{{ config.inputError }}</div>\n  <div class=\"weui-dialog__ft\">\n    <a\n      href=\"#\"\n      *ngFor=\"let item of config.btns\"\n      class=\"weui-dialog__btn weui-dialog__btn_{{ item.type }}\"\n      (click)=\"_onSelect(item)\"\n      >{{ item.text }}</a\n    >\n  </div>\n</div>\n",
                    preserveWhitespaces: false,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None
                }] }
    ];
    /** @nocollapse */
    DialogComponent.ctorParameters = function () { return [
        { type: DialogConfig },
        { type: ChangeDetectorRef }
    ]; };
    DialogComponent.propDecorators = {
        config: [{ type: Input }],
        open: [{ type: Output }],
        close: [{ type: Output }],
        container: [{ type: ViewChild, args: ['container',] }]
    };
    return DialogComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var DialogService = /** @class */ (function (_super) {
    __extends(DialogService, _super);
    function DialogService(resolver, applicationRef, injector, doc) {
        return _super.call(this, resolver, applicationRef, injector, doc) || this;
    }
    /**
     * 创建一个对话框并显示
     *
     * @param data 对话框配置项
     * @returns 可订阅来获取结果
     */
    /**
     * 创建一个对话框并显示
     *
     * @param {?} data 对话框配置项
     * @return {?} 可订阅来获取结果
     */
    DialogService.prototype.show = /**
     * 创建一个对话框并显示
     *
     * @param {?} data 对话框配置项
     * @return {?} 可订阅来获取结果
     */
    function (data) {
        var _this = this;
        /** @type {?} */
        var componentRef = this.build(DialogComponent);
        componentRef.instance.config = data;
        componentRef.instance.close.subscribe((/**
         * @return {?}
         */
        function () {
            setTimeout((/**
             * @return {?}
             */
            function () { return _this.destroy(componentRef); }), 300);
        }));
        return componentRef.instance.show();
    };
    DialogService.decorators = [
        { type: Injectable, args: [{ providedIn: 'root' },] }
    ];
    /** @nocollapse */
    DialogService.ctorParameters = function () { return [
        { type: ComponentFactoryResolver },
        { type: ApplicationRef },
        { type: Injector },
        { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
    ]; };
    /** @nocollapse */ DialogService.ngInjectableDef = defineInjectable({ factory: function DialogService_Factory() { return new DialogService(inject(ComponentFactoryResolver), inject(ApplicationRef), inject(INJECTOR), inject(DOCUMENT)); }, token: DialogService, providedIn: "root" });
    return DialogService;
}(BaseService));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var DialogModule = /** @class */ (function () {
    function DialogModule() {
    }
    DialogModule.decorators = [
        { type: NgModule, args: [{
                    imports: [CommonModule, FormsModule, MaskModule, FormModule, SliderModule],
                    declarations: [DialogComponent],
                    exports: [DialogComponent],
                    entryComponents: [DialogComponent],
                },] }
    ];
    return DialogModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { DialogComponent, DialogConfig, DialogModule, DialogService };
//# sourceMappingURL=ngx-weui-dialog.js.map
