import { __decorate, __metadata } from 'tslib';
import { trigger, state, style, transition, animate } from '@angular/animations';
import { Component, ChangeDetectionStrategy, ViewEncapsulation, Input, Output, EventEmitter, NgModule } from '@angular/core';
import { genImageUrl, InputBoolean } from 'ngx-weui/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var GalleryComponent = /** @class */ (function () {
    function GalleryComponent() {
        /**
         * 是否允许删除，默认：`true`
         */
        this.canDelete = true;
        /**
         * 删除回调
         */
        this.delete = new EventEmitter();
        /**
         * 隐藏回调
         */
        this.hide = new EventEmitter();
        /**
         * 标记是否显示，支持双向绑定
         */
        this.show = false;
        this.showChange = new EventEmitter();
        this._showd = false;
    }
    Object.defineProperty(GalleryComponent.prototype, "imgs", {
        /**
         * 图片数据
         *
         * - 虽然支持传递数组，但并不支持在打开后切换图片。
         */
        set: /**
         * 图片数据
         *
         * - 虽然支持传递数组，但并不支持在打开后切换图片。
         * @param {?} val
         * @return {?}
         */
        function (val) {
            this.parseImgs(val);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(GalleryComponent.prototype, "_visibility", {
        get: /**
         * @return {?}
         */
        function () {
            return this.show ? 'show' : 'hide';
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    GalleryComponent.prototype._antStart = /**
     * @return {?}
     */
    function () {
        if (this.show)
            this._showd = this.show;
    };
    /**
     * @return {?}
     */
    GalleryComponent.prototype._antDone = /**
     * @return {?}
     */
    function () {
        this._showd = this.show;
    };
    /**
     * @param {?} item
     * @return {?}
     */
    GalleryComponent.prototype._onDel = /**
     * @param {?} item
     * @return {?}
     */
    function (item) {
        if (this.canDelete) {
            this.delete.emit(item);
            this._onHide();
        }
        return false;
    };
    /**
     * @return {?}
     */
    GalleryComponent.prototype._onHide = /**
     * @return {?}
     */
    function () {
        this.show = false;
        this.showChange.emit(this.show);
        this.hide.emit();
    };
    /**
     * @private
     * @param {?} imgs
     * @return {?}
     */
    GalleryComponent.prototype.parseImgs = /**
     * @private
     * @param {?} imgs
     * @return {?}
     */
    function (imgs) {
        if (Array.isArray(imgs)) {
            if (imgs.length > 0) {
                if (typeof imgs[0] === 'string') {
                    imgs = ((/** @type {?} */ (imgs))).map((/**
                     * @param {?} url
                     * @return {?}
                     */
                    function (url) {
                        return { url: url };
                    }));
                }
                else {
                    imgs = ((/** @type {?} */ (imgs))).map((/**
                     * @param {?} item
                     * @return {?}
                     */
                    function (item) {
                        if (item.file)
                            item.url = genImageUrl(item.file);
                        return item;
                    }));
                }
            }
        }
        else {
            if (typeof imgs === 'string') {
                imgs = [{ url: imgs }];
            }
            else {
                /** @type {?} */
                var imgUrl = genImageUrl(imgs);
                if (imgUrl) {
                    imgs = [{ url: imgUrl }];
                }
            }
        }
        // todo: 永远只返回一个
        // 针对未来可能直接上下个
        this._imgs = imgs && ((/** @type {?} */ (imgs))).length > 0 ? imgs.slice(0, 1) : [];
    };
    GalleryComponent.decorators = [
        { type: Component, args: [{
                    selector: 'weui-gallery',
                    exportAs: 'weuiGallery',
                    template: "<div *ngIf=\"_imgs\" class=\"weui-galleries\">\n  <ng-template ngFor let-item [ngForOf]=\"_imgs\">\n    <div\n      class=\"weui-gallery\"\n      [ngStyle]=\"{ display: _showd ? 'block' : 'none' }\"\n      [@visibility]=\"_visibility\"\n      (@visibility.start)=\"_antStart($event)\"\n      (@visibility.done)=\"_antDone($event)\"\n      (click)=\"_onHide()\"\n    >\n      <span class=\"weui-gallery__img\" [ngStyle]=\"{ 'background-image': 'url(' + item?.url + ')' }\"></span>\n      <div class=\"weui-gallery__opr\" *ngIf=\"canDelete\">\n        <a href=\"#\" class=\"weui-gallery__del\" (click)=\"_onDel(item)\">\n          <i class=\"weui-icon-delete weui-icon_gallery-delete\"></i>\n        </a>\n      </div>\n    </div>\n  </ng-template>\n</div>\n",
                    animations: [
                        trigger('visibility', [
                            state('show', style({ opacity: 1 })),
                            state('hide', style({ opacity: 0 })),
                            transition('hide <=> show', [animate(200)]),
                        ]),
                    ],
                    preserveWhitespaces: false,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None
                }] }
    ];
    GalleryComponent.propDecorators = {
        imgs: [{ type: Input }],
        canDelete: [{ type: Input }],
        delete: [{ type: Output }],
        hide: [{ type: Output }],
        show: [{ type: Input }],
        showChange: [{ type: Output }]
    };
    __decorate([
        InputBoolean(),
        __metadata("design:type", Boolean)
    ], GalleryComponent.prototype, "canDelete", void 0);
    __decorate([
        InputBoolean(),
        __metadata("design:type", Boolean)
    ], GalleryComponent.prototype, "show", void 0);
    return GalleryComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var GalleryModule = /** @class */ (function () {
    function GalleryModule() {
    }
    GalleryModule.decorators = [
        { type: NgModule, args: [{
                    imports: [CommonModule],
                    declarations: [GalleryComponent],
                    exports: [GalleryComponent],
                    entryComponents: [GalleryComponent],
                },] }
    ];
    return GalleryModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { GalleryComponent, GalleryModule };
//# sourceMappingURL=ngx-weui-gallery.js.map
