import { defineInjectable, Injectable, Component, forwardRef, ChangeDetectionStrategy, ViewEncapsulation, ChangeDetectorRef, Input, Output, EventEmitter, NgModule } from '@angular/core';
import { __assign, __decorate, __metadata } from 'tslib';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { InputBoolean } from 'ngx-weui/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var RatingConfig = /** @class */ (function () {
    function RatingConfig() {
        /**
         * 图标数量（默认：5个）
         */
        this.max = 5;
        /**
         * 样式名
         */
        this.cls = '';
        /**
         * 未选中图标，默认：`weui-icon-circle`
         */
        this.stateOff = 'weui-icon-circle';
        /**
         * 选中图标，默认：`weui-icon-success`
         */
        this.stateOn = 'weui-icon-success';
        /**
         * 自定义图标，当存在时 `max`、`stateOff`、`stateOn` 失效
         */
        this.states = [];
        /**
         * 图标 `title` 属性值，默认以 `1` 开始的索引值
         */
        this.titles = [];
    }
    RatingConfig.decorators = [
        { type: Injectable, args: [{ providedIn: 'root' },] }
    ];
    /** @nocollapse */ RatingConfig.ngInjectableDef = defineInjectable({ factory: function RatingConfig_Factory() { return new RatingConfig(); }, token: RatingConfig, providedIn: "root" });
    return RatingConfig;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var RatingComponent = /** @class */ (function () {
    function RatingComponent(DEF, cdr) {
        this.DEF = DEF;
        this.cdr = cdr;
        /**
         * 是否只读模式，默认：`false`
         */
        this.readonly = false;
        /**
         * 选中后回调，参数：选中值
         */
        this.selected = new EventEmitter();
        this._class = '';
        this.onChange = Function.prototype;
    }
    /**
     * @private
     * @param {?} cog
     * @return {?}
     */
    RatingComponent.prototype.setConfig = /**
     * @private
     * @param {?} cog
     * @return {?}
     */
    function (cog) {
        /** @type {?} */
        var _c = __assign({ states: [] }, this.DEF, cog);
        this._class = _c.cls || '';
        /** @type {?} */
        var count = _c.states.length || _c.max;
        this._range = Array(count)
            .fill(0)
            .map((/**
         * @param {?} _v
         * @param {?} i
         * @return {?}
         */
        function (_v, i) {
            return __assign({ index: i, on: _c.stateOn, off: _c.stateOff, title: (/** @type {?} */ (_c.titles))[i] || i + 1 }, (_c.states[i] || {}));
        }));
        this.cdr.detectChanges();
    };
    /**
     * @param {?} changes
     * @return {?}
     */
    RatingComponent.prototype.ngOnChanges = /**
     * @param {?} changes
     * @return {?}
     */
    function (changes) {
        if (changes.config) {
            this.setConfig(changes.config.currentValue);
        }
    };
    /**
     * @param {?} value
     * @return {?}
     */
    RatingComponent.prototype._rate = /**
     * @param {?} value
     * @return {?}
     */
    function (value) {
        if (!this.readonly && value >= 0 && value <= this._range.length) {
            this.writeValue(value);
            this.onChange(value);
        }
        this.cdr.detectChanges();
    };
    /**
     * @param {?} _value
     * @return {?}
     */
    RatingComponent.prototype.writeValue = /**
     * @param {?} _value
     * @return {?}
     */
    function (_value) {
        if (_value % 1 !== _value) {
            this._value = Math.round(_value);
            this._preValue = _value;
            this.cdr.detectChanges();
            return;
        }
        this._preValue = _value;
        this._value = _value;
        this.cdr.detectChanges();
    };
    // private onTouched: any = Function.prototype;
    // private onTouched: any = Function.prototype;
    /**
     * @param {?} fn
     * @return {?}
     */
    RatingComponent.prototype.registerOnChange = 
    // private onTouched: any = Function.prototype;
    /**
     * @param {?} fn
     * @return {?}
     */
    function (fn) {
        this.onChange = fn;
    };
    /**
     * @param {?} _fn
     * @return {?}
     */
    RatingComponent.prototype.registerOnTouched = /**
     * @param {?} _fn
     * @return {?}
     */
    function (_fn) {
        // this.onTouched = fn;
    };
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    RatingComponent.prototype.setDisabledState = /**
     * @param {?} isDisabled
     * @return {?}
     */
    function (isDisabled) {
        this.readonly = isDisabled;
    };
    RatingComponent.decorators = [
        { type: Component, args: [{
                    selector: 'weui-rating',
                    exportAs: 'weuiRating',
                    template: "<span\n  class=\"weui-rating__container{{ _class ? ' ' + _class : '' }}\"\n  tabindex=\"0\"\n  role=\"slider\"\n  aria-valuemin=\"0\"\n  [attr.aria-valuemax]=\"_range.length\"\n  [attr.aria-valuenow]=\"_value\"\n>\n  <ng-template ngFor let-r [ngForOf]=\"_range\" let-index=\"index\">\n    <span class=\"weui-rating__sr-only\">({{ index < _value ? '*' : ' ' }})</span>\n    <i (click)=\"_rate(index + 1)\" [ngClass]=\"index < _value ? r.on : r.off\" [title]=\"r.title\"></i>\n  </ng-template>\n</span>\n",
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef((/**
                             * @return {?}
                             */
                            function () { return RatingComponent; })),
                            multi: true,
                        },
                    ],
                    preserveWhitespaces: false,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None
                }] }
    ];
    /** @nocollapse */
    RatingComponent.ctorParameters = function () { return [
        { type: RatingConfig },
        { type: ChangeDetectorRef }
    ]; };
    RatingComponent.propDecorators = {
        config: [{ type: Input }],
        readonly: [{ type: Input }],
        selected: [{ type: Output }]
    };
    __decorate([
        InputBoolean(),
        __metadata("design:type", Boolean)
    ], RatingComponent.prototype, "readonly", void 0);
    return RatingComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var RatingModule = /** @class */ (function () {
    function RatingModule() {
    }
    RatingModule.decorators = [
        { type: NgModule, args: [{
                    imports: [CommonModule],
                    declarations: [RatingComponent],
                    exports: [RatingComponent],
                },] }
    ];
    return RatingModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { RatingComponent, RatingConfig, RatingModule };
//# sourceMappingURL=ngx-weui-rating.js.map
