import { __decorate, __metadata } from 'tslib';
import { Component, forwardRef, ChangeDetectionStrategy, ViewEncapsulation, ChangeDetectorRef, Input, HostBinding, Output, ViewChild, EventEmitter, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR, FormsModule } from '@angular/forms';
import { InputNumber, InputBoolean } from 'ngx-weui/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Stepper 步进器，支持 `[(ngModel)]`
 */
var StepperComponent = /** @class */ (function () {
    function StepperComponent(cdr) {
        this.cdr = cdr;
        this.onChange = Function.prototype;
        // private onTouched: any = Function.prototype;
        this._step = 1;
        this._precisionStep = 0;
        this._precisionFactor = 1;
        this._disabledMinus = false;
        this._disabledPlus = false;
        /**
         * 最小值
         */
        this.min = -Infinity;
        /**
         * 最大值
         */
        this.max = Infinity;
        /**
         * 禁用
         */
        this.disabled = false;
        /**
         * 变更时回调
         */
        this.change = new EventEmitter();
    }
    Object.defineProperty(StepperComponent.prototype, "step", {
        /** 步长，可以为小数 */
        get: /**
         * 步长，可以为小数
         * @return {?}
         */
        function () {
            return this._step;
        },
        set: /**
         * @param {?} value
         * @return {?}
         */
        function (value) {
            this._step = value;
            /** @type {?} */
            var stepString = value.toString();
            if (stepString.indexOf('e-') >= 0) {
                this._precisionStep = parseInt(stepString.slice(stepString.indexOf('e-')), 10);
            }
            if (stepString.indexOf('.') >= 0) {
                this._precisionStep = stepString.length - stepString.indexOf('.') - 1;
            }
            this._precisionFactor = Math.pow(10, this._precisionStep);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StepperComponent.prototype, "value", {
        get: /**
         * @return {?}
         */
        function () {
            return this._value;
        },
        set: /**
         * @param {?} value
         * @return {?}
         */
        function (value) {
            if (isNaN(value) || value === this.value)
                return;
            value = +value;
            if (value > this.max) {
                this._value = this.max;
                this.onChange(this.max);
            }
            else if (value < this.min) {
                this._value = this.min;
                this.onChange(this.min);
            }
            else {
                this._value = value;
                this._checkDisabled();
            }
            this.cdr.detectChanges();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @template THIS
     * @this {THIS}
     * @return {THIS}
     */
    StepperComponent.prototype._checkDisabled = /**
     * @template THIS
     * @this {THIS}
     * @return {THIS}
     */
    function () {
        (/** @type {?} */ (this))._disabledPlus = (/** @type {?} */ (this)).disabled || !((/** @type {?} */ (this)).value + (/** @type {?} */ (this)).step <= (/** @type {?} */ (this)).max);
        (/** @type {?} */ (this))._disabledMinus = (/** @type {?} */ (this)).disabled || !((/** @type {?} */ (this)).value - (/** @type {?} */ (this)).step >= (/** @type {?} */ (this)).min);
        return (/** @type {?} */ (this));
    };
    /**
     * @return {?}
     */
    StepperComponent.prototype._notify = /**
     * @return {?}
     */
    function () {
        this.change.emit(this.value);
        this.onChange(this.value);
    };
    /**
     * @return {?}
     */
    StepperComponent.prototype._plus = /**
     * @return {?}
     */
    function () {
        if (this.value === undefined)
            this.value = this.max || 0;
        this._checkDisabled();
        if (this._disabledPlus)
            return;
        this.value = this._toPrecisionAsStep((this._precisionFactor * this.value + this._precisionFactor * this.step) / this._precisionFactor);
        this._checkDisabled()._notify();
    };
    /**
     * @return {?}
     */
    StepperComponent.prototype._minus = /**
     * @return {?}
     */
    function () {
        if (this.value === undefined)
            this.value = this.min || 0;
        this._checkDisabled();
        if (this._disabledMinus)
            return;
        this.value = this._toPrecisionAsStep((this._precisionFactor * this.value - this._precisionFactor * this.step) / this._precisionFactor);
        this._checkDisabled()._notify();
    };
    /**
     * @return {?}
     */
    StepperComponent.prototype._blur = /**
     * @return {?}
     */
    function () {
        /** @type {?} */
        var el = this._inputNumber.nativeElement;
        this.value = +el.value;
        el.value = this.value.toString();
        this._checkDisabled()._notify();
    };
    /**
     * @param {?} num
     * @return {?}
     */
    StepperComponent.prototype._toPrecisionAsStep = /**
     * @param {?} num
     * @return {?}
     */
    function (num) {
        if (isNaN(num) || num === '') {
            return num;
        }
        return Number(Number(num).toFixed(this._precisionStep));
    };
    /**
     * @param {?} value
     * @return {?}
     */
    StepperComponent.prototype.writeValue = /**
     * @param {?} value
     * @return {?}
     */
    function (value) {
        this.value = value;
        this._checkDisabled();
    };
    /**
     * @param {?} fn
     * @return {?}
     */
    StepperComponent.prototype.registerOnChange = /**
     * @param {?} fn
     * @return {?}
     */
    function (fn) {
        this.onChange = fn;
    };
    /**
     * @param {?} _fn
     * @return {?}
     */
    StepperComponent.prototype.registerOnTouched = /**
     * @param {?} _fn
     * @return {?}
     */
    function (_fn) {
        // this.onTouched = fn;
    };
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    StepperComponent.prototype.setDisabledState = /**
     * @param {?} isDisabled
     * @return {?}
     */
    function (isDisabled) {
        this.disabled = isDisabled;
    };
    StepperComponent.decorators = [
        { type: Component, args: [{
                    selector: 'weui-stepper',
                    exportAs: 'weuiStepper',
                    template: "<span class=\"minus\" [ngClass]=\"{ disabled: _disabledMinus }\" (click)=\"_minus()\"><em>-</em></span>\n<div class=\"input\">\n  <input\n    type=\"tel\"\n    #inputNumber\n    [(ngModel)]=\"value\"\n    (blur)=\"_blur()\"\n    [disabled]=\"disabled\"\n    [attr.min]=\"min\"\n    [attr.max]=\"max\"\n    [attr.step]=\"_step\"\n    autocomplete=\"off\"\n  />\n</div>\n<span class=\"plus\" [ngClass]=\"{ disabled: _disabledPlus }\" (click)=\"_plus()\"><em>+</em></span>\n",
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef((/**
                             * @return {?}
                             */
                            function () { return StepperComponent; })),
                            multi: true,
                        },
                    ],
                    preserveWhitespaces: false,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None
                }] }
    ];
    /** @nocollapse */
    StepperComponent.ctorParameters = function () { return [
        { type: ChangeDetectorRef }
    ]; };
    StepperComponent.propDecorators = {
        min: [{ type: Input }],
        max: [{ type: Input }],
        disabled: [{ type: Input }, { type: HostBinding, args: ['class.disabled',] }],
        change: [{ type: Output }],
        _inputNumber: [{ type: ViewChild, args: ['inputNumber',] }],
        step: [{ type: Input }]
    };
    __decorate([
        InputNumber(),
        __metadata("design:type", Number)
    ], StepperComponent.prototype, "min", void 0);
    __decorate([
        InputNumber(),
        __metadata("design:type", Number)
    ], StepperComponent.prototype, "max", void 0);
    __decorate([
        InputBoolean(),
        __metadata("design:type", Boolean)
    ], StepperComponent.prototype, "disabled", void 0);
    __decorate([
        InputNumber(),
        __metadata("design:type", Number),
        __metadata("design:paramtypes", [Number])
    ], StepperComponent.prototype, "step", null);
    return StepperComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var StepperModule = /** @class */ (function () {
    function StepperModule() {
    }
    StepperModule.decorators = [
        { type: NgModule, args: [{
                    imports: [CommonModule, FormsModule],
                    declarations: [StepperComponent],
                    exports: [StepperComponent],
                },] }
    ];
    return StepperModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { StepperComponent, StepperModule };
//# sourceMappingURL=ngx-weui-stepper.js.map
